@@ -1,21 +1,9 @@
-/***************************************************************************
- *   Copyright 2009 Chani Armitage <chani@kde.org>
- *   Copyright 2010 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Library General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Chani Armitage <chani@kde.org>
+    SPDX-FileCopyrightText: 2010 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "mouseinputbutton.h"
 #include "mouseinputbutton_p.h"
@@ -46,7 +34,7 @@ Palapeli::MouseInputButton::MouseInputButton(QWidget* parent)
 {
 	qRegisterMetaType<Palapeli::Trigger>();
 	connect(this, &QAbstractButton::clicked, this, &MouseInputButton::captureTrigger);
-	connect(m_clearButton, SIGNAL(clicked()), SLOT(clearTrigger()));
+	connect(m_clearButton, &FlatButton::clicked, this, &MouseInputButton::clearTrigger);
 	setCheckable(true);
 	m_iconLabel->setPixmap(QIcon::fromTheme( QStringLiteral( "input-mouse" )).pixmap(22)); //TODO: respect global icon size configuration
 	//setup child widgets
@@ -67,7 +55,7 @@ Palapeli::MouseInputButton::MouseInputButton(QWidget* parent)
 	QStyleOptionButton opt;
 	QPushButton::initStyleOption(&opt);
 	const QSize bareSizeHint = layout->sizeHint();
-	const QSize fullSizeHint = style()->sizeFromContents(QStyle::CT_PushButton, &opt, bareSizeHint, this).expandedTo(QApplication::globalStrut());
+	const QSize fullSizeHint = style()->sizeFromContents(QStyle::CT_PushButton, &opt, bareSizeHint, this);
 	const int marginX = (fullSizeHint.width() - bareSizeHint.width()) / 2;
 	const int marginY = (fullSizeHint.height() - bareSizeHint.height()) / 2;
 	layout->setContentsMargins(marginX, marginY, marginX, marginY);
@@ -152,7 +140,9 @@ bool Palapeli::MouseInputButton::event(QEvent* event)
 				const QWheelEvent* wEvent = static_cast<QWheelEvent*>(event);
 				Palapeli::Trigger newTrigger;
 				newTrigger.setModifiers(wEvent->modifiers());
-				newTrigger.setWheelDirection(wEvent->orientation());
+				const QPoint angleDelta = wEvent->angleDelta();
+				const Qt::Orientation orientation = (qAbs(angleDelta.x()) > qAbs(angleDelta.y()) ? Qt::Horizontal : Qt::Vertical);
+				newTrigger.setWheelDirection(orientation);
 				setTrigger(newTrigger);
 				event->accept();
 				return true;
@@ -216,7 +206,7 @@ void Palapeli::MouseInputButton::setTrigger(const Palapeli::Trigger& trigger)
 	if (m_requiresValidation && trigger.isValid() && m_trigger != trigger)
 	{
 		m_stagedTrigger = trigger;
-		emit triggerRequest(trigger);
+		Q_EMIT triggerRequest(trigger);
 	}
 	else
 		applyTrigger(trigger);
@@ -251,7 +241,7 @@ void Palapeli::MouseInputButton::applyTrigger(const Palapeli::Trigger& trigger)
 	updateAppearance();
 	//announce change
 	if (announceChange)
-		emit triggerChanged(trigger);
+		Q_EMIT triggerChanged(trigger);
 }
 
 void Palapeli::MouseInputButton::showModifiers(Qt::KeyboardModifiers modifiers)
