@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2010 Johannes Loehnert <loehnert.kde@gmx.de>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Johannes Loehnert <loehnert.kde@gmx.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "puzzlepreview.h"
 
@@ -128,7 +116,7 @@ void Palapeli::PuzzlePreview::closeEvent(QCloseEvent* event)
 {
 	// Triggered by the preview window's Close button.
 	event->accept();
-	emit closing();
+	Q_EMIT closing();
 }
 
 void Palapeli::PuzzlePreview::writeConfigIfGeometryChanged()
