@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2009 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "loadingwidget.h"
 
@@ -30,7 +18,7 @@ Palapeli::LoadingWidget::LoadingWidget(QWidget* parent)
 {
 	setMinimumSize(QSize(64, 64));
 	m_updateTimer->setInterval(30);
-	connect(m_updateTimer, SIGNAL(timeout()), this, SLOT(update()));
+	connect(m_updateTimer, &QTimer::timeout, this, QOverload<>::of(&QWidget::update));
 }
 
 void Palapeli::LoadingWidget::showEvent(QShowEvent* event)
